class Bitmask26:
    def __init__(self, arg0: str) -> None: ...
    def __eq__(self, arg0: Bitmask26) -> bool: ...
    def __hash__(self) -> int: ...
    def __repr__(self) -> str: ...
    def __ge__(self, arg0: Bitmask26) -> bool: ...
